@@ -15,3 +15,6 @@ DBUS_EXEC_FAILED     = 'org.freedesktop.DBus.Error.Spawn.ExecFailed'
 DBUS_NO_REPLY        = 'org.freedesktop.DBus.Error.NoReply'
 DBUS_NOT_SUPPORTED   = 'org.freedesktop.DBus.Error.NotSupported'
 DBUS_NO_SUCH_OBJECT  = 'org.freedesktop.Secret.Error.NoSuchObject'
+
+ALGORITHM_PLAIN = 'plain'
+ALGORITHM_DH = 'dh-ietf1024-sha256-aes128-cbc-pkcs7'
